pub enum Event {
Tempo(u32),
TimeSignature(u8, u8, u8, u8),
KeySignature(i8, bool),
Midi(MidiEvent),
}Expand description
Represents a single MIDI event.
Variants
Tempo(u32)
Represents a tempo change message.
The wrapped u32 represents microseconds per beat.
TimeSignature(u8, u8, u8, u8)
In order of the MIDI specification, numerator, denominator, MIDI clocks per click, 32nd notes per quarter.
KeySignature(i8, bool)
As in the MIDI specification, negative numbers indicate number of flats and positive numbers indicate number of sharps. false indicates a major scale, true indicates a minor scale.
Midi(MidiEvent)
Represents a MIDI event.